@@ -395,7 +395,12 @@ def show(
             pts = (pts * np.array([[w, h]])).astype(np.uint16).tolist()
         ax.scatter(*zip(*pts), c=kwargs.pop("pts_color", "red"))
     if conns is not None:
-        for start_ix, end_ix, meta in conns:
+        for i in range(len(conns)):
+            if len(conns[i]) == 2:
+                start_ix, end_ix = conns[i]
+                meta = 1
+            else:
+                start_ix, end_ix, meta = conns[i]
             _x, _y = bbs[start_ix].xc, bbs[start_ix].yc
             _X, _Y = bbs[end_ix].xc, bbs[end_ix].yc
             _dx, _dy = _X - _x, _Y - _y
@@ -660,46 +665,6 @@ def lzip(*x):
     return list(zip(*x))
 
 
-# def to_absolute(input, shape):
-#     if isinstance(shape, np.ndarray) and shape.ndim >= 2:
-#         shape = shape.shape[:2]
-#     h, w = shape
-#     if isinstance(input, BB):
-#         return input.absolute((h, w))
-#     elif isinstance(input, pd.DataFrame):
-
-#         def _round(x):
-#             return np.round(x.values.astype(np.double)).astype(np.uint16)
-
-#         df = input.copy()
-#         df["x"] = _round(df.x * w)
-#         df["X"] = _round(df.X * w)
-#         df["y"] = _round(df.y * h)
-#         df["Y"] = _round(df.Y * h)
-#         return df
-#     elif isinstance(input, list):
-#         bbs = bbfy(input)
-#         return [bb.absolute((h, w)) for bb in bbs]
-
-
-# def to_relative(input, shape):
-#     if isinstance(shape, np.ndarray) and shape.ndim >= 2:
-#         shape = shape.shape[:2]
-#     h, w = shape
-#     if isinstance(input, BB):
-#         return input.relative((h, w))
-#     elif isinstance(input, pd.DataFrame):
-#         df = input.copy()
-#         df["x"] = df.x / w
-#         df["X"] = df.X / w
-#         df["y"] = df.y / h
-#         df["Y"] = df.Y / h
-#         return df
-#     elif isinstance(input, list):
-#         bbs = bbfy(input)
-#         return [bb.relative((h, w)) for bb in bbs]
-
-
 from fastcore.basics import patch_to
 
 
